#
# spec file for package SDL2_sound
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL2_sound
%define lname	libSDL2_sound2
Version:        2.0.4
Release:        1.1
Summary:        Sound Sample Library for SDL (Simple DirectMedia Layer)
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://icculus.org/SDL_sound/

Source:         https://github.com/icculus/SDL_sound/archive/refs/tags/v%version.tar.gz
BuildRequires:  c_compiler
BuildRequires:  cmake
BuildRequires:  pkgconfig(sdl2)
Provides:       bundled(dr_flac) = 0.12.42
Provides:       bundled(dr_mp3) = 0.6.38
Provides:       bundled(libmodplug)
Provides:       bundled(stb_vorbis) = 1.22

%description
SDL_sound is a library that handles the decoding of several popular
sound file formats, such as wav, ogg mp3 and midi. SDL_sound can just
play a file or alternatively decode a file and hand back a single
pointer to the waveform. SDL_sound also can handle channel conversion
on-the-fly and behind-the-scenes.

%package -n %lname
Summary:        Sound Sample Library for SDL (Simple DirectMedia Layer)
Group:          System/Libraries

%description -n %lname
SDL_sound is a library that handles the decoding of several popular
sound file formats, such as wav, ogg mp3 and midi. SDL_sound can just
play a file or alternatively decode a file and hand back a single
pointer to the waveform. SDL_sound also can handle channel conversion
on-the-fly and behind-the-scenes.

%package devel
Summary:        Development files for the SDL sound sample library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       pkgconfig(sdl2)
Conflicts:      SDL_sound-devel

%description devel
SDL_sound is a library that handles the decoding of several popular
sound file formats, such as wav, ogg mp3 and midi. SDL_sound can just
play a file or alternatively decode a file and hand back a single
pointer to the waveform. SDL_sound also can handle channel conversion
on-the-fly and behind-the-scenes.

%prep
%autosetup -n SDL_sound-%version -p1

%build
%cmake -DSDLSOUND_BUILD_STATIC:BOOL=OFF
%cmake_build

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE.txt
%_libdir/lib*.so.*

%files devel
%_bindir/playsound*
%_includedir/SDL2/
%_libdir/cmake/
%_libdir/lib*.so
%_libdir/pkgconfig/*.pc

%changelog
* Mon Jan 13 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.4
  * Update bundled stb_vorbis to address CVE-2023-45676,
    CVE-2023-45677, CVE-2023-45679, CVE-2023-45680,
    CVE-2023-45681, CVE-2023-45682.
* Fri Nov  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.2
  * No further changes from the last snapshot 2.0.1+g60
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2.0.1+g60 (53f66a30)
  * Avoid division by zero with certain uncompressed WAV files
  * A pkgconfig file was added
* Wed Mar 30 2022 Jan Engelhardt <jengelh@inai.de>
- Move to 2.0.1.g17 (df3fc77)
  * Resolve build failures on Leap 15.3
* Sat Mar 26 2022 Jan Engelhardt <jengelh@inai.de>
- New package SDL2_sound for build.opensuse.org. In comparison to
  SDL_sound (1.x):
  * Removed support for QuickTime, Speex and MikMod
  * SDL_sound 2's public API has not changed at all from 1.x
  * SDL_sound.h requires SDL2 now (can't mix SDL2_sound with SDL1)
  * The library name changed to -lSDL2_sound
- Drop SDL_sound-1.0.3-nompglib.patch, no longer applies
- Drop baselibs.conf
